from django.contrib import admin

from les_assets_generator.app.models import Asset, Parameter


class ParameterTabularInline(admin.TabularInline):
    model = Parameter
    extra = 1


class AssetAdmin(admin.ModelAdmin):
    inlines = [
        ParameterTabularInline,
    ]


admin.site.register(Asset, AssetAdmin)



"""
Django settings for assets_generator project.

Generated by 'django-admin startproject' using Django 4.0.6.

For more information on this file, see
https://docs.djangoproject.com/en/4.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/4.0/ref/settings/
"""

import os

import dj_database_url
from dotenv import load_dotenv

load_dotenv()

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
PROJECT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
BASE_DIR = os.path.dirname(PROJECT_DIR)


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/4.0/howto/deployment/checklist/


# Application definition

INSTALLED_APPS = [
    "les_assets_generator.app.apps.AppConfig",
    "colorfield",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "allauth",
    "allauth.account",
    "allauth.socialaccount",
    "allauth.socialaccount.providers.google",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
]

ROOT_URLCONF = "les_assets_generator.assets_generator.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [os.path.join(BASE_DIR, "templates")],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "django.template.context_processors.request",
            ],
        },
    },
]

WSGI_APPLICATION = "les_assets_generator.assets_generator.wsgi.application"


# Database
# https://docs.djangoproject.com/en/4.0/ref/settings/#databases

DATABASES = {"default": dj_database_url.config(default="sqlite:///db.sqlite3")}


# Password validation
# https://docs.djangoproject.com/en/4.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
    },
]

# Logging
LOGGING = {
    "version": 1,
    "disable_existing_loggers": False,
    "handlers": {
        "console": {
            "class": "logging.StreamHandler",
        },
    },
    "loggers": {
        "debug": {
            "handlers": ["console"],
            "level": os.getenv("DJANGO_LOG_LEVEL", "INFO"),
            "propagate": True,
        },
    },
    "root": {
        "handlers": ["console"],
        "level": "WARNING",
    },
}

# Internationalization
# https://docs.djangoproject.com/en/4.0/topics/i18n/

LANGUAGE_CODE = "fr-fr"

TIME_ZONE = "Europe/Paris"

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/4.0/howto/static-files/

STATIC_ROOT = os.path.join(BASE_DIR, "static")
STATIC_URL = "/static/"
STATICFILES_DIRS = [
    os.path.join(BASE_DIR, "staticfiles"),
]

MEDIA_ROOT = os.path.join(BASE_DIR, "media")
MEDIA_URL = "/media/"

# Default primary key field type
# https://docs.djangoproject.com/en/4.0/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

AUTHENTICATION_BACKENDS = (
    "django.contrib.auth.backends.ModelBackend",
    "allauth.account.auth_backends.AuthenticationBackend",
)

SITE_ID = 1

# django-allauth settings
LOGIN_REDIRECT_URL = "/admin/"
SOCIALACCOUNT_QUERY_EMAIL = True
ACCOUNT_LOGOUT_ON_GET = True
ACCOUNT_UNIQUE_EMAIL = True
ACCOUNT_EMAIL_REQUIRED = True
SOCIALACCOUNT_ADAPTER = (
    "les_assets_generator.assets_generator.allauth.CustomSocialAccountAdapter"
)
SOCIALACCOUNT_PROVIDERS = {
    "google": {
        "SCOPE": [
            "profile",
            "email",
        ],
        "AUTH_PARAMS": {
            "access_type": "online",
        },
    }
}



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['les_assets_generator',
 'les_assets_generator.app',
 'les_assets_generator.app.migrations',
 'les_assets_generator.assets_generator',
 'les_assets_generator.assets_generator.settings']

package_data = \
{'': ['*'],
 'les_assets_generator': ['assets/*',
                          'locale/fr/LC_MESSAGES/*',
                          'staticfiles/css/*',
                          'staticfiles/img/logo/*',
                          'templates/admin/*']}

install_requires = \
['Django>=4.0.6,<5.0.0',
 'Pillow>=9.2.0,<10.0.0',
 'dj-database-url>=1.0.0,<2.0.0',
 'django-allauth>=0.51.0,<0.52.0',
 'django-colorfield>=0.7.2,<0.8.0',
 'gunicorn>=20.1.0,<21.0.0',
 'python-dotenv>=0.20.0,<0.21.0']

setup_kwargs = {
    'name': 'les-assets-generator',
    'version': '0.1.0',
    'description': '',
    'long_description': 'Lyon e-Sport assets generator\n\nThis website help you to generate assets from an image and GET parameters\n\n![Python test](https://github.com/lyon-esport/assets-generator/workflows/Python%20test/badge.svg)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\n# Requirements\n- Python (check version in pyproject.toml)\n\n# Install\n```\npip install les-assets-generator\n```\n\n# Dev\nInstall [Poetry](https://python-poetry.org/docs/master/#installing-with-the-official-installer) with version >= 1.2.0a1\n\nInstall and setup dependencies\n```\npoetry install\npoetry shell\npre-commit install\n\n```\n\n### Run pre-commit\n```\npre-commit run --all-files\n```\n\n# Configuration\n### Production only\n\nSet the environnement for production (.env file or env vars)\n\n```dotenv\n# Django allowed host like .lyon-esport.fr\nDJANGO_ALLOWED_HOST = ""\n\n# Django log level\nDJANGO_LOG_LEVEL = ""\n\n# Set the secret key for session and other thinks\nSECRET_KEY = ""\n\n# Set allowed google email domain like lyon-esport.fr\nGOOGLE_DOMAIN = ""\n```\n\n# Run\nDev: les_assets_generator.assets_generator.settings.dev\nProd: les_assets_generator.assets_generator.settings.production\n\n    $ export DJANGO_SETTINGS_MODULE="les_assets_generator.assets_generator.settings.production"\n    $ cd les_assets_generator\n    $ python -m les_assets_generator.manage makemigrations\n    $ python -m les_assets_generator.manage migrate\n    $ python -m les_assets_generator.manage compilemessages\n\n## Dev\n\n    $ python -m les_assets_generator.manage runserver\n\n## Production\n\n    $ python -m les_assets_generator.manage collectstatic --settings=assets_generator.settings.production --noinput\n    $ gunicorn les_assets_generator.assets_generator.wsgi:application --bind 0.0.0.0:8000 --workers 3\n\n# i18n\nhttps://docs.djangoproject.com/en/4.1/topics/i18n/translation/#message-files\n\n# Licence\n\nThe code is under CeCILL license.\n\nYou can find all details here: https://cecill.info/licences/Licence_CeCILL_V2.1-en.html\n\n# Credits\n\nCopyright © Lyon e-Sport, 2022\n\nContributor(s):\n\n-Ortega Ludovic - ludovic.ortega@lyon-esport.fr\n',
    'author': 'Ludovic Ortega',
    'author_email': 'ludovic.ortega@lyon-esport.fr',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/lyon-esport/assets-generator',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
